==> V04.051.zip: tweet_live-V04.051/web/enmi16/session-1/config.php <==
<?php
$config = array(
    'hashtag'    => '#enmi16',

    'title' => 'Entretiens du Nouveau Monde Industriel 2016 - Session 1',

    'abstract'   => "<b>PENSER L’EXOSOMATISATION POUR DEFENDRE LA SOCIETE</b><br><em>Paris. Centre Pompidou. Grande Salle.<br>13 et 14 décembre 2016</em>",

    'description' => "<h3>Session 1 : Exosomatisation et avenir de la société</h3>
    <br>
    <p><strong>mardi 13 Décembre 2016</strong></p>
    <p>L'”augmentation” des organes organiques de l’homme par des organes artificiels – organologiques en cela – est définitoire de l’hominisation dès l’origine. Présenter l’augmentation de l’homme comme une radicale nouveauté est à cet égard une imposture. Il n’en reste pas moins que l’organogenèse exosomatique contemporaine présente des caractères tout à fait inédits.</p>
    <p><strong>Intervenants</strong> : Serge Lasvignes (Président du Centre Georges Pompidou), Bernard Stiegler (philosophe, Institut de recherche et d’innovation), Antoine Missemer (économiste, CNRS) : \"Exosomatisation et théorie économique chez Nicholas Georgescu-Roegen\", Paolo Vignola (philosophe, Yachai university) : \"Vivre et penser comme des Pokémons. Notes pour une pharmacologie de l’immanence.\"</p>",

   'link' => 'http://enmi-conf.org/wp/enmi15/',

   'islive'     => true,

   'keywords'   => 'iri, nouveau monde industriel, medecine 3.0, exosomatisation',

   'rep' => basename(__DIR__),

   'partenaires'=> "Organisateurs: <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>
   | <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a>
    - Partenaires:<a href='http://www.univ-paris8.fr/MSH-Paris-Nord-Maison-des-Sciences-de-l-Homme' class='footerLink' target='_blank'>CNRS-MSH Paris Nord</a>
   | <a href='http://www.orange.com/fr/accueil' class='footerLink' target='_blank'>Orange</a>
   | <a href='http://www.3ds.com/' class='footerLink' target='_blank'>Dassault Systèmes</a>
   | <a href='http://www.plainecommune.fr' class='footerLink' target='_blank'>Plaine Commune</a>
   | <a href='https://www.utc.fr/' class='footerLink' target='_blank'>UTC</a>
   | <a href='http://www.fondationdefrance.org/' class='footerLink' target='_blank'>Fondation de France</a>",

    'client_visual' => 'images/client_visual.jpg',// 480 × 320 pixels

    'head_logo' => 'images/logo-enmi.png', // 171 × 63 pixels

    'slide_background' => 'images/slide_background.jpg', // 606 × 282 pixels

    'archive_img' => 'images/archive_img.jpg', // 270 × 150 pixels

    'archive_title' => "Entretiens du Nouveau Monde Industriel 2016",
    'archive_description' => 'par l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>au Centre Pompidou les 13 et 14 décembre 2016',

    // After the event
    'metadata'    => "1cae7116-c136-11e6-89a8-00145ea4a2be",
    'annotation_protocol_version' => '2',
);

==> V04.052.zip: tweet_live-V04.052/web/enmi16/session-1/config.php <==
<?php
$config = array(
    'hashtag'    => '#enmi16',

    'title' => 'Entretiens du Nouveau Monde Industriel 2016 - Session 1',

    'abstract'   => "<b>PENSER L’EXOSOMATISATION POUR DEFENDRE LA SOCIETE</b><br><em>Paris. Centre Pompidou. Grande Salle.<br>13 et 14 décembre 2016</em>",

    'description' => "<h3>Session 1 : Exosomatisation et avenir de la société</h3>
    <br>
    <p><strong>mardi 13 Décembre 2016</strong></p>
    <p>L'”augmentation” des organes organiques de l’homme par des organes artificiels – organologiques en cela – est définitoire de l’hominisation dès l’origine. Présenter l’augmentation de l’homme comme une radicale nouveauté est à cet égard une imposture. Il n’en reste pas moins que l’organogenèse exosomatique contemporaine présente des caractères tout à fait inédits.</p>
    <p><strong>Intervenants</strong> : Serge Lasvignes (Président du Centre Georges Pompidou), Bernard Stiegler (philosophe, Institut de recherche et d’innovation), Antoine Missemer (économiste, CNRS) : \"Exosomatisation et théorie économique chez Nicholas Georgescu-Roegen\", Paolo Vignola (philosophe, Yachai university) : \"Vivre et penser comme des Pokémons. Notes pour une pharmacologie de l’immanence.\"</p>",

   'link' => 'http://enmi-conf.org/wp/enmi16/session-1/',

   'islive'     => true,

   'keywords'   => 'iri, nouveau monde industriel, medecine 3.0, exosomatisation',

   'rep' => basename(__DIR__),

   'partenaires'=> "Organisateurs: <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>
   | <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a>
    - Partenaires:<a href='http://www.univ-paris8.fr/MSH-Paris-Nord-Maison-des-Sciences-de-l-Homme' class='footerLink' target='_blank'>CNRS-MSH Paris Nord</a>
   | <a href='http://www.orange.com/fr/accueil' class='footerLink' target='_blank'>Orange</a>
   | <a href='http://www.3ds.com/' class='footerLink' target='_blank'>Dassault Systèmes</a>
   | <a href='http://www.plainecommune.fr' class='footerLink' target='_blank'>Plaine Commune</a>
   | <a href='https://www.utc.fr/' class='footerLink' target='_blank'>UTC</a>
   | <a href='http://www.fondationdefrance.org/' class='footerLink' target='_blank'>Fondation de France</a>",

    'client_visual' => 'images/client_visual.jpg',// 480 × 320 pixels

    'head_logo' => 'images/logo-enmi.png', // 171 × 63 pixels

    'slide_background' => 'images/slide_background.jpg', // 606 × 282 pixels

    'archive_img' => 'images/archive_img.jpg', // 270 × 150 pixels

    'archive_title' => "Entretiens du Nouveau Monde Industriel 2016",
    'archive_description' => 'par l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>au Centre Pompidou les 13 et 14 décembre 2016',

    // After the event
    'metadata'    => "1cae7116-c136-11e6-89a8-00145ea4a2be",
    'annotation_protocol_version' => '2',
);
